@@ -369,6 +369,7 @@ MYLOG(DETAIL_LOG_LEVEL, "hlen=" FORMAT_SSIZE_T "\n", hlen);
 			"%s"		/* INIKEEPALIVE TIME/INTERVAL */
 			ABBR_NUMERIC_AS "=%d;"
 			INI_OPTIONAL_ERRORS "=%d;"
+			INI_FETCHREFCURSORS "=%d;"
 #ifdef	_HANDLE_ENLIST_IN_DTC_
 			INI_XAOPT "=%d"	/* XAOPT */
 #endif /* _HANDLE_ENLIST_IN_DTC_ */
@@ -403,6 +404,7 @@ MYLOG(DETAIL_LOG_LEVEL, "hlen=" FORMAT_SSIZE_T "\n", hlen);
 			,makeKeepaliveConnectString(keepaliveStr, sizeof(keepaliveStr), ci, FALSE)
 			,ci->numeric_as
 			,ci->optional_errors
+			,ci->fetch_refcursors
 #ifdef	_HANDLE_ENLIST_IN_DTC_
 			,ci->xa_opt
 #endif /* _HANDLE_ENLIST_IN_DTC_ */
@@ -461,6 +463,8 @@ MYLOG(DETAIL_LOG_LEVEL, "hlen=" FORMAT_SSIZE_T "\n", hlen);
 			flag |= BIT_LOWERCASEIDENTIFIER;
 		if (ci->optional_errors)
 			flag |= BIT_OPTIONALERRORS;
+		if (ci->fetch_refcursors)
+			flag |= BIT_FETCHREFCURSORS;
 
 		if (ci->sslmode[0])
 		{
@@ -583,6 +587,7 @@ unfoldCXAttribute(ConnInfo *ci, const char *value)
 	ci->use_server_side_prepare = (char)((flag & BIT_USESERVERSIDEPREPARE) != 0);
 	ci->lower_case_identifier = (char)((flag & BIT_LOWERCASEIDENTIFIER) != 0);
 	ci->optional_errors = (char)((flag & BIT_OPTIONALERRORS) != 0);
+	ci->fetch_refcursors = (char)((flag & BIT_FETCHREFCURSORS) != 0);
 }
 
 BOOL
@@ -793,6 +798,8 @@ copyConnAttributes(ConnInfo *ci, const char *attribute, const char *value)
 		ci->drivers.bools_as_char = atoi(value);
 	else if (stricmp(attribute, INI_EXTRASYSTABLEPREFIXES) == 0 || stricmp(attribute, ABBR_EXTRASYSTABLEPREFIXES) == 0)
 		STRCPY_FIXED(ci->drivers.extra_systable_prefixes, value);
+	else if (stricmp(attribute, INI_FETCHREFCURSORS) == 0 || stricmp(attribute, ABBR_FETCHREFCURSORS) == 0)
+		ci->fetch_refcursors = atoi(value);
 	else
 		found = FALSE;
 
@@ -842,6 +849,7 @@ getCiDefaults(ConnInfo *ci)
 				ci->wcs_debug = 1;
 	}
 	ci->disable_convert_func = 0;
+	ci->fetch_refcursors = DEFAULT_FETCHREFCURSORS;
 #ifdef	_HANDLE_ENLIST_IN_DTC_
 	ci->xa_opt = DEFAULT_XAOPT;
 #endif /* _HANDLE_ENLIST_IN_DTC_ */
@@ -1082,6 +1090,9 @@ MYLOG(0, "drivername=%s\n", drivername);
 	if (SQLGetPrivateProfileString(DSN, INI_SSLMODE, NULL_STRING, temp, sizeof(temp), ODBC_INI) > 0)
 		STRCPY_FIXED(ci->sslmode, temp);
 
+	if (SQLGetPrivateProfileString(DSN, INI_FETCHREFCURSORS, NULL_STRING, temp, sizeof(temp), ODBC_INI) > 0)
+		ci->fetch_refcursors = atoi(temp);
+
 #ifdef	_HANDLE_ENLIST_IN_DTC_
 	if (SQLGetPrivateProfileString(DSN, INI_XAOPT, NULL_STRING, temp, sizeof(temp), ODBC_INI) > 0)
 		ci->xa_opt = atoi(temp);
@@ -1374,6 +1385,11 @@ writeDSNinfo(const ConnInfo *ci)
 								 INI_IGNORETIMEOUT,
 								 temp,
 								 ODBC_INI);
+	ITOA_FIXED(temp, ci->fetch_refcursors);
+	SQLWritePrivateProfileString(DSN,
+								 INI_FETCHREFCURSORS,
+								 temp,
+								 ODBC_INI);
 #ifdef	_HANDLE_ENLIST_IN_DTC_
 	ITOA_FIXED(temp, ci->xa_opt);
 	SQLWritePrivateProfileString(DSN, INI_XAOPT, temp, ODBC_INI);
@@ -1789,6 +1805,7 @@ CC_conninfo_init(ConnInfo *conninfo, UInt4 option)
 	conninfo->batch_size = DEFAULT_BATCH_SIZE;
 	conninfo->ignore_timeout = DEFAULT_IGNORETIMEOUT;
 	conninfo->wcs_debug = -1;
+	conninfo->fetch_refcursors = -1;
 #ifdef	_HANDLE_ENLIST_IN_DTC_
 	conninfo->xa_opt = -1;
 #endif /* _HANDLE_ENLIST_IN_DTC_ */
@@ -1890,6 +1907,7 @@ CC_copy_conninfo(ConnInfo *ci, const ConnInfo *sci)
 	CORR_VALCPY(keepalive_interval);
 	CORR_VALCPY(batch_size);
 	CORR_VALCPY(ignore_timeout);
+	CORR_VALCPY(fetch_refcursors);
 #ifdef	_HANDLE_ENLIST_IN_DTC_
 	CORR_VALCPY(xa_opt);
 #endif
